#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pid1
version:              0.1.3.1
visibility:           public
id:                   pid1-0.1.3.1-7YxuN8hVPs0xWJeLYuSiD
key:                  pid1-0.1.3.1-7YxuN8hVPs0xWJeLYuSiD
license:              MIT
copyright:            2016 Michael Snoyman
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/fpco/pid1#readme
synopsis:
    Do signal handling and orphan reaping for Unix PID1 init processes

description:
    Please see README.md or view Haddocks at <https://www.stackage.org/package/pid1>

category:             System
abi:                  746ee5de67a102962b26cc3b271a573d
exposed:              True
exposed-modules:      System.Process.PID1
import-dirs:          /usr/lib/ghc-9.6.6/site-local/pid1-0.1.3.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pid1-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pid1-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pid1
hs-libraries:         HSpid1-0.1.3.1-7YxuN8hVPs0xWJeLYuSiD
depends:
    base-4.18.2.1 directory-1.3.8.5 process-1.6.19.0 unix-2.8.4.0

haddock-interfaces:   /usr/share/doc/haskell-pid1/html/pid1.haddock
haddock-html:         /usr/share/doc/haskell-pid1/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

